@@ -1,4 +1,4 @@
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
 # I/O related command processor methods
 
 use warnings;
@@ -55,6 +55,11 @@ sub msg($$;$) {
 
   }
 
+sub msg_need_running($$;$) {
+    my($self, $prefix, $opts) = @_;
+    $self->errmsg("$prefix not available when terminated");
+}
+
 sub msg_nocr($$;$) {
     my($self, $message, $opts) = @_;
     $message = $self->safe_rep($message) unless $self->{opts}{unlimited};
